@@ -85,7 +85,7 @@ stanc_process <- function(file, model_code = '', model_name = "anon_model",
   model_code <- gsub('#include /(.*$)', '#include "\\1"', model_code)
   has_pound <- any(grepl("#", model_code, fixed = TRUE))
 
-  if (has_pound && isFALSE(auto_format)) {
+  if (FALSE && has_pound && isFALSE(auto_format)) {
     unprocessed <- tempfile(fileext = ".stan")
     processed <- tempfile(fileext = ".stan")
     on.exit(file.remove(unprocessed))
@@ -230,7 +230,7 @@ stanc <- function(file, model_code = '', model_name = "anon_model",
   model_cppcode <- try(stanc_ctx$call("stanc", model_cppname, model_code, stanc_flags),
                        silent = TRUE)
   if (inherits(model_cppcode, "try-error")) {
-    stop("parser failed badly")
+    stop("parser failed badly; maybe try installing the V8 package")
   } else if (length(model_cppcode$errors)) {
     model_cppcode$status <- FALSE
     stop(paste(model_cppcode$errors, collapse = "\n"))
