@@ -44,8 +44,7 @@ SEXP is_Null_NS(SEXP ns) {
   LOGICAL(ans)[0] = 1;
   PROTECT(ns);
   if (TYPEOF(ns) == EXTPTRSXP) {
-    // Rprintf("ptr=%p.\n", EXTPTR_PTR(ns));
-    if (EXTPTR_PTR(ns) != NULL) LOGICAL(ans)[0] = 0;
+    if (R_ExternalPtrAddr(ns) != NULL) LOGICAL(ans)[0] = 0;
   }
   UNPROTECT(2);
   return ans;
